%define ALD_Ver		1.2.4

Name:         flex

License:      BSD
Summary:      This is flex, the fast lexical analyzer generator.
Group:        Development/Compilers
Version:      2.5.37
Release:      4

Source: %{name}-%{version}.tar.xz
Source1: CROSS.sh

%define DestDir		/Compiler
# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
%define target %{_arch}-%{_vendor}-%{_os}%{__isa_bits}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin

%define __os_install_post %{nil}

%define _srcrpmdir %{_topdir}/SRPMS/tmp

%define CrossDestDir	/Cross

%else  #_CROSS

%define csysdir		%{nil}
%define csysbindir	/usr/bin
%define CrossDestDir	%{nil}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}

%define target %{_arch}-%{_os}%{_gnu}

%endif # !_CROSS

%define docdir %{_defaultdocdir}/%{name}

# ------------------- description ------------------------------------
%description
flex is a tool for generating scanners: programs which recognize
lexical patterns in text.

More information about flex as well as the latest official release of
flex can be found at:

http://flex.sourceforge.net/
#-------------------------------
%package info
Summary:      Info for %{name}
Group:        Documentation
%description info
Info for %{name}
#-------------------------------
%package pdf
Summary:      pdf for %{name}
Group:        Documentation
%description pdf
pdf for %{name}

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif


%if %{_arch} == "i386"
OPTFLAGS="-Os -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os -fno-asynchronous-unwind-tables"
%endif
%if %{_arch} == "arm"
OPTFLAGS="-Os -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
%endif

CFLAGS="$OPTFLAGS -ffunction-sections -fdata-sections -fno-tree-loop-optimize -fno-tree-dominator-opts -fno-strength-reduce -fno-stack-protector -std=gnu99"
LDFLAGS="-Wl,--gc-sections"

%if %{_CROSS} && (%{_os} != "mingw")
export ac_cv_func_fork_works="yes"
export ac_cv_func_vfork_works="yes"
%if %{_arch} == "arm"
export ac_cv_func_malloc_0_nonnull="yes"
export ac_cv_func_realloc_0_nonnull="yes"
%endif
%endif

%configure \
%if %{_CROSS}
	--build=%{_build} \
	--host=%{target} \
%endif
	--disable-nls \
	--disable-rpath \
	&>FConfigure_log.txt

make &>FMake_log.txt


# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt

cp THANKS $RPM_BUILD_ROOT%{docdir}/

rm -rf $RPM_BUILD_ROOT%{_infodir}/dir
rm $RPM_BUILD_ROOT%{docdir}/ONEWS
rm $RPM_BUILD_ROOT%{docdir}/TODO

%if %{_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=0
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
%endif #_CROSS

%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean 

DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
%if %{_os} == "mingw"
  rm %{name}-$SE
%else  #mingw
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-info-$SE $DD/%{name}-info-$DE
  mv %{name}-pdf-$SE $DD/%{name}-pdf-$DE
%endif #!mingw
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
%if (%{_os} == "mingw")
  TMP_TO=$DD
%else
  TMP_TO=$DD/tar
%endif
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r usr $tmp/
%if (%{_os} == "mingw")
  zip -9 -r $tmp.zip $tmp >/dev/null
  mv $tmp.zip $TMP_TO
%else
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
%endif
  rm -r $tmp
%endif  #BUILD_TAR

# ------------------- Files ------------------------------------------
%if %{_os} == "mingw"
%Files
%{_prefix}
%else  #!mingw

%Files
%{_bindir}
%{_libdir}
%{_includedir}
%{_mandir}
%exclude %{docdir}/*.pdf
%{docdir}

%files info
%{_infodir}

%files pdf
%{docdir}/*.pdf
%endif #!mingw
